==> bootstrap-styled-saga-0.0.1.tgz: package/README.md <==
# bootstrap-styled-saga

bootstrap-styled-saga will help you fetch theme to your bootstrap-styled-redux `ConnectedBootstrapProvider`.

**Master**

[![build status](https://module.kopaxgroup.com/bootstrap-styled/bootstrap-styled-saga/badges/master/build.svg)](https://module.kopaxgroup.com/bootstrap-styled/bootstrap-styled-saga/commits/master)
[![coverage report](https://module.kopaxgroup.com/bootstrap-styled/bootstrap-styled-saga/badges/master/coverage.svg)](https://module.kopaxgroup.com/bootstrap-styled/bootstrap-styled-saga/commits/master)

**Dev**

[![build status](https://module.kopaxgroup.com/bootstrap-styled/bootstrap-styled-saga/badges/dev/build.svg)](https://module.kopaxgroup.com/bootstrap-styled/bootstrap-styled-saga/commits/dev)
[![coverage report](https://module.kopaxgroup.com/bootstrap-styled/bootstrap-styled-saga/badges/dev/coverage.svg)](https://module.kopaxgroup.com/bootstrap-styled/bootstrap-styled-saga/commits/dev)


## Table of Contents

  - [Changelog](#changelog)
  - [Documentation](#documentation)
  - [License](#license)

---

## Changelog

  - View [Changelog](CHANGELOG.md)
  
## Documentation

  - View [Markdown documentation](docs)
  - View bootstrap-styled-saga [HTML documentation](https://bootstrap-styled.yeutech.com/bootstrap-styled-saga) *(require access)*
  - View rollup-umd [HTML documentation](https://dev-tools.yeutech.com/rollup-umd) *(require access)*

## License

Copyright (c) 2018 Yeutech Company Limited. For more information `contact@yeutech.com`. Made with [rollup-umd](https://module.kopaxgroup.com/dev-tools/rollup-umd/tags/0.8.7) 0.8.7

==> bootstrap-styled-saga-0.1.1.tgz: package/README.md <==
# bootstrap-styled-saga

bootstrap-styled-saga will help you fetch theme to your bootstrap-styled-redux `ConnectedBootstrapProvider`.

**Master**

[![build status](https://module.kopaxgroup.com/bootstrap-styled/bootstrap-styled-saga/badges/master/build.svg)](https://module.kopaxgroup.com/bootstrap-styled/bootstrap-styled-saga/commits/master)
[![coverage report](https://module.kopaxgroup.com/bootstrap-styled/bootstrap-styled-saga/badges/master/coverage.svg)](https://module.kopaxgroup.com/bootstrap-styled/bootstrap-styled-saga/commits/master)

**Dev**

[![build status](https://module.kopaxgroup.com/bootstrap-styled/bootstrap-styled-saga/badges/dev/build.svg)](https://module.kopaxgroup.com/bootstrap-styled/bootstrap-styled-saga/commits/dev)
[![coverage report](https://module.kopaxgroup.com/bootstrap-styled/bootstrap-styled-saga/badges/dev/coverage.svg)](https://module.kopaxgroup.com/bootstrap-styled/bootstrap-styled-saga/commits/dev)


## Table of Contents

  - [Changelog](#changelog)
  - [Documentation](#documentation)
  - [License](#license)

---

## Changelog

  - View [Changelog](CHANGELOG.md)
  
## Documentation

  - View [Markdown documentation](docs)
  - View bootstrap-styled-saga [HTML documentation](https://bootstrap-styled.yeutech.com/bootstrap-styled-saga)
  - View rollup-umd [HTML documentation](https://dev-tools.yeutech.com/rollup-umd) *(require access)*

## License

Licensed under the MIT License, Copyright © 2017-present Yeutech Company Limited.

See [LICENSE](LICENSE.md) for more information.
